# Table of Contents

- [calculations-for-ai-agents](<./calculations-for-ai-agents.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Calculations for AI Agents](<./Calculations-for-AI-Agents.md>)
  - [Overview](<./Calculations-for-AI-Agents/Overview.md>)
  - [Prerequisites](<./Calculations-for-AI-Agents/Prerequisites.md>)
  - [Calculation Templates](<./Calculations-for-AI-Agents/Calculation-Templates.md>)
